pub struct Point {
    pub timestamp: i64,
}
Point in Time

This is simply a timestamp according to UNIX convention, that is, the number of seconds since 1970-01-01 00:00:00. Negative values represent time before that epoch, obviously.

Because it is an i64, the date range that can be represented is very large, roughly from the year -292_277_022_657 to +292_277_024_626. However, working with Points close to end of this range is a bad idea, as (internal) date math operations will be likely to overflow. For instance, Calendar::lookup will overflow for Points with a timestamp close to i64::MAX because it first adds the 1970 years of the UNIX epoch back to the value.

Fields

timestamp: i64

Count of seconds since 1970-01-01 00:00:00

Implementations

Same as constructing Point {timestamp} directly

Get the current Point in time from the system clock